Change log
==========

`Next version`_
~~~~~~~~~~~~~~~


`0.1`_ (2018-02-26)
~~~~~~~~~~~~~~~~~~~

- Initial public version.

.. _0.1: https://github.com/matthiask/django-only-staff/commit/89bb93c5cdba
.. _0.2: https://github.com/matthiask/django-only-staff/compare/0.1...0.2
.. _Next version: https://github.com/matthiask/django-only-staff/compare/0.1...master
